@@ -163,9 +163,7 @@ mime_update_program_done (GPid     pid,
 		/* FIXME: what is the right thing to do here??  We're going to
 		 * have to rethink the gnome-vfs APIs.
 		 */
-		g_print ("updating the database\n");
 		gnome_vfs_mime_reload ();
-		g_print ("done updating\n");
 	}
 }
 
@@ -552,6 +550,10 @@ eel_mime_set_default_application (const char *mime_type,
 	GError *error = NULL;
 	gboolean ret;
 
+	if (!ensure_application_dir ()) {
+		return FALSE;
+	}
+	
 	applications_dir = get_user_dir ("applications");
 	list_filename = g_build_filename (applications_dir, "defaults.list", NULL);
 
